@@ -19,8 +19,8 @@
 
 package jxl.biff;
 
-import common.Assert;
-import common.Logger;
+import jxl.common.Assert;
+import jxl.common.Logger;
 
 import java.text.MessageFormat;
 import java.text.DecimalFormat;
@@ -31,6 +31,7 @@ import jxl.WorkbookSettings;
 import jxl.biff.formula.ExternalSheet;
 import jxl.biff.formula.FormulaException;
 import jxl.biff.formula.FormulaParser;
+import jxl.biff.formula.ParseContext;
 
 /**
  * Class which parses the binary data associated with Data Validity (DV)
@@ -307,7 +308,7 @@ public class DVParser
   public DVParser(byte[] data, 
                   ExternalSheet es, 
                   WorkbookMethods nt,
-                  WorkbookSettings ws) throws FormulaException
+                  WorkbookSettings ws)
   {
     Assert.verify(nt != null);
 
@@ -419,24 +420,33 @@ public class DVParser
 
     // Do the formulas
 
-    // First, create a temporary  blank cell for any formula relative 
-    // references
-    EmptyCell tmprt = new EmptyCell(column1, row1);
-
-    if (formula1Length != 0)
+    try
     {
-      byte[] tokens = new byte[formula1Length];
-      System.arraycopy(data, formula1Pos, tokens, 0, formula1Length);
-      formula1 = new FormulaParser(tokens, tmprt, es, nt,ws);
-      formula1.parse();
+      // First, create a temporary  blank cell for any formula relative 
+      // references
+      EmptyCell tmprt = new EmptyCell(column1, row1);
+
+      if (formula1Length != 0)
+      {
+        byte[] tokens = new byte[formula1Length];
+        System.arraycopy(data, formula1Pos, tokens, 0, formula1Length);
+        formula1 = new FormulaParser(tokens, tmprt, es, nt,ws);
+        formula1.parse();
+      }
+
+      if (formula2Length != 0)
+      {
+        byte[] tokens = new byte[formula2Length];
+        System.arraycopy(data, formula2Pos, tokens, 0, formula2Length);
+        formula2 = new FormulaParser(tokens, tmprt, es, nt, ws);
+        formula2.parse();
+      }
     }
-
-    if (formula2Length != 0)
+    catch (FormulaException e)
     {
-      byte[] tokens = new byte[formula2Length];
-      System.arraycopy(data, formula2Pos, tokens, 0, formula2Length);
-      formula2 = new FormulaParser(tokens, tmprt, es, nt, ws);
-      formula2.parse();
+      logger.warn(e.getMessage() + " for cells " + 
+      CellReferenceHelper.getCellReference(column1, row1)+ "-" + 
+      CellReferenceHelper.getCellReference(column2, row2));
     }
   }
 
@@ -900,7 +910,8 @@ public class DVParser
   /**
    * Called by the cell value when the cell features are added to the sheet
    */
-  public void setCell(int col, int row, 
+  public void setCell(int col, 
+                      int row, 
                       ExternalSheet es, 
                       WorkbookMethods nt,
                       WorkbookSettings ws) throws FormulaException
@@ -911,13 +922,15 @@ public class DVParser
     column2 = col;
 
     formula1 = new FormulaParser(formula1String,
-                                 es, nt, ws);
+                                 es, nt, ws, 
+                                 ParseContext.DATA_VALIDATION);
     formula1.parse();
 
     if (formula2String != null)
     {
       formula2 = new FormulaParser(formula2String,
-                                   es, nt, ws);
+                                   es, nt, ws, 
+                                   ParseContext.DATA_VALIDATION);
       formula2.parse();
     }
   }
