@@ -122,6 +122,7 @@ public class Write
     // Add a named range to the workbook
     workbook.addNameArea("namedrange", s4, 1, 11, 5, 14);
     workbook.addNameArea("validation_range", s1, 4, 65, 9, 65);
+    workbook.addNameArea("formulavalue", s6, 1, 45, 1, 45);
 
     // Add a print area to the "Labels" sheet
     s5.getSettings().setPrintArea(4,4,15,35);
@@ -1063,7 +1064,8 @@ public class Write
       s1.addCell(l);
 
       File file = new File("../jexcelapi/docs/index.html");
-      wh = new WritableHyperlink(0, 32, 8, 32, file);
+      wh = new WritableHyperlink(0, 32, 8, 32, file, 
+                                 "JExcelApi Documentation");
       s1.addHyperlink(wh);
 
       // Add a hyperlink to another cell on this sheet
@@ -1372,7 +1374,7 @@ public class Write
       ws.addCell(l2);
     }
 
-    // Add in a last label which doesn't take the common format
+    // Add in a last label which doesn't take the jxl.common.format
     wf = new WritableFont(WritableFont.TIMES, 10, WritableFont.BOLD);
     wf.setColour(Colour.RED);
     WritableCellFormat wcf2 = new WritableCellFormat(wf);
@@ -1657,6 +1659,14 @@ public class Write
     ws.addCell(f);
     l = new Label(3, 44, "F29+F34+F41+F48+F55+F62+F69+F76+F83+F90+F97+F104+F111+F118+F125+F132+F139+F146+F153+F160+F167+F174+F181+F188+F195+F202+F209+F216+F223+F230+F237+F244+F251+F258+F265+F272+F279+F286+F293+F300+F305+F308");
     ws.addCell(l);
+
+    nc = new Number(1,45, 17);
+    ws.addCell(nc);
+    f = new Formula(2, 45, "formulavalue+5");
+    ws.addCell(f);
+    l = new Label(3, 45, "formulavalue+5");
+    ws.addCell(l);
+    
     // Errors
     /*
     f = new Formula(2, 25, "PLOP(15)"); // unknown function
