@@ -23,8 +23,8 @@ import java.util.ArrayList;
 import java.util.HashMap;
 import java.util.Iterator;
 
-import common.Assert;
-import common.Logger;
+import jxl.common.Assert;
+import jxl.common.Logger;
 
 import jxl.Cell;
 import jxl.CellFeatures;
@@ -51,6 +51,7 @@ import jxl.biff.Type;
 import jxl.biff.WorkspaceInformationRecord;
 import jxl.biff.drawing.Button;
 import jxl.biff.drawing.Chart;
+import jxl.biff.drawing.CheckBox;
 import jxl.biff.drawing.ComboBox;
 import jxl.biff.drawing.Comment;
 import jxl.biff.drawing.Drawing;
@@ -1608,147 +1609,197 @@ final class SheetReader
     
     try
     {
-    // Handle images
-    if (objRecord.getType() == ObjRecord.PICTURE)
-    {
-      if (drawingData == null)
+      // Handle images
+      if (objRecord.getType() == ObjRecord.PICTURE)
       {
-        drawingData = new DrawingData();
+        if (drawingData == null)
+        {
+          drawingData = new DrawingData();
+        }
+
+        Drawing drawing = new Drawing(msoRecord,
+                                      objRecord,
+                                      drawingData,
+                                      workbook.getDrawingGroup(),
+                                      sheet);
+        drawings.add(drawing);
+        return;
       }
 
-      Drawing drawing = new Drawing(msoRecord,
-                                    objRecord,
-                                    drawingData,
-                                    workbook.getDrawingGroup(),
-                                    sheet);
-      drawings.add(drawing);
-      return;
-    }
-
-    // Handle comments
-    if (objRecord.getType() == ObjRecord.EXCELNOTE)
-    {
-      if (drawingData == null)
+      // Handle comments
+      if (objRecord.getType() == ObjRecord.EXCELNOTE)
       {
-        drawingData = new DrawingData();
-      }
+        if (drawingData == null)
+        {
+          drawingData = new DrawingData();
+        }
 
-      Comment comment = new Comment(msoRecord,
-                                    objRecord,
-                                    drawingData,
-                                    workbook.getDrawingGroup(),
-                                    workbookSettings);
+        Comment comment = new Comment(msoRecord,
+                                      objRecord,
+                                      drawingData,
+                                      workbook.getDrawingGroup(),
+                                      workbookSettings);
+
+        // Sometimes Excel writes out Continue records instead of drawing
+        // records, so forcibly hack all of these into a drawing record
+        Record r2 = excelFile.next();
+        if (r2.getType() == Type.MSODRAWING || r2.getType() == Type.CONTINUE)
+        {
+          MsoDrawingRecord mso = new MsoDrawingRecord(r2);
+          comment.addMso(mso);
+          r2 = excelFile.next();
+        }
+        Assert.verify(r2.getType() == Type.TXO);
+        TextObjectRecord txo = new TextObjectRecord(r2);
+        comment.setTextObject(txo);
 
-      // Sometimes Excel writes out Continue records instead of drawing
-      // records, so forcibly hack all of these into a drawing record
-      Record r2 = excelFile.next();
-      if (r2.getType() == Type.MSODRAWING || r2.getType() == Type.CONTINUE)
-      {
-        MsoDrawingRecord mso = new MsoDrawingRecord(r2);
-        comment.addMso(mso);
         r2 = excelFile.next();
-      }
-      Assert.verify(r2.getType() == Type.TXO);
-      TextObjectRecord txo = new TextObjectRecord(r2);
-      comment.setTextObject(txo);
+        Assert.verify(r2.getType() == Type.CONTINUE);
+        ContinueRecord text = new ContinueRecord(r2);
+        comment.setText(text);
 
-      r2 = excelFile.next();
-      Assert.verify(r2.getType() == Type.CONTINUE);
-      ContinueRecord text = new ContinueRecord(r2);
-      comment.setText(text);
-
-      r2 = excelFile.next();
-      if (r2.getType() == Type.CONTINUE)
-      {
-        ContinueRecord formatting = new ContinueRecord(r2);
-        comment.setFormatting(formatting);
-      }
-
-      comments.put(new Integer(comment.getObjectId()), comment);
-      return;
-    }
-
-    // Handle combo boxes
-    if (objRecord.getType() == ObjRecord.COMBOBOX)
-    {
-      if (drawingData == null)
-      {
-        drawingData = new DrawingData();
-      }
-
-      ComboBox comboBox = new ComboBox(msoRecord,
-                                       objRecord,
-                                       drawingData,
-                                       workbook.getDrawingGroup(),
-                                       workbookSettings);
-      drawings.add(comboBox);
-      return;
-    }
-
-    // Handle form buttons
-    if (objRecord.getType() == ObjRecord.BUTTON)
-    {
-      if (drawingData == null)
-      {
-        drawingData = new DrawingData();
-      }
-
-      Button button = new Button(msoRecord,
-                                 objRecord,
-                                 drawingData,
-                                 workbook.getDrawingGroup(),
-                                 workbookSettings);
-
-      Record r2 = excelFile.next();
-      if (r2.getType() == Type.MSODRAWING)
-      {
-        MsoDrawingRecord mso = new MsoDrawingRecord(r2);
-        button.addMso(mso);
         r2 = excelFile.next();
+        if (r2.getType() == Type.CONTINUE)
+        {
+          ContinueRecord formatting = new ContinueRecord(r2);
+          comment.setFormatting(formatting);
+        }
+
+        comments.put(new Integer(comment.getObjectId()), comment);
+        return;
       }
-      Assert.verify(r2.getType() == Type.TXO);
-      TextObjectRecord txo = new TextObjectRecord(r2);
-      button.setTextObject(txo);
 
-      r2 = excelFile.next();
-      Assert.verify(r2.getType() == Type.CONTINUE);
-      ContinueRecord text = new ContinueRecord(r2);
-      button.setText(text);
-
-      r2 = excelFile.next();
-      if (r2.getType() == Type.CONTINUE)
+      // Handle combo boxes
+      if (objRecord.getType() == ObjRecord.COMBOBOX)
       {
-        ContinueRecord formatting = new ContinueRecord(r2);
-        button.setFormatting(formatting);
+        if (drawingData == null)
+        {
+          drawingData = new DrawingData();
+        }
+
+        ComboBox comboBox = new ComboBox(msoRecord,
+                                         objRecord,
+                                         drawingData,
+                                         workbook.getDrawingGroup(),
+                                         workbookSettings);
+        drawings.add(comboBox);
+        return;
       }
-
-      drawings.add(button);
-
-      return;
-    }
-
-    // Handle other types
-    if (objRecord.getType() != ObjRecord.CHART)
-    {
-      logger.warn(objRecord.getType() + " on sheet \"" +
-                  sheet.getName() +
-                  "\" not supported - omitting");
-
-      if (drawingData == null)
+    
+      // Handle check boxes
+      if (objRecord.getType() == ObjRecord.CHECKBOX)
       {
-        drawingData = new DrawingData();
+        if (drawingData == null)
+        {
+          drawingData = new DrawingData();
+        }
+
+        CheckBox checkBox = new CheckBox(msoRecord,
+                                         objRecord,
+                                         drawingData,
+                                         workbook.getDrawingGroup(),
+                                         workbookSettings);
+
+        Record r2 = excelFile.next();
+        Assert.verify(r2.getType() == Type.MSODRAWING || 
+                      r2.getType() == Type.CONTINUE);
+        if (r2.getType() == Type.MSODRAWING || r2.getType() == Type.CONTINUE)
+        {
+          MsoDrawingRecord mso = new MsoDrawingRecord(r2);
+          checkBox.addMso(mso);
+          r2 = excelFile.next();
+        }
+
+        Assert.verify(r2.getType() == Type.TXO);
+        TextObjectRecord txo = new TextObjectRecord(r2);
+        checkBox.setTextObject(txo);
+
+        if (txo.getTextLength() == 0)
+        {
+          return;
+        }
+
+        r2 = excelFile.next();
+        Assert.verify(r2.getType() == Type.CONTINUE);
+        ContinueRecord text = new ContinueRecord(r2);
+        checkBox.setText(text);
+
+        r2 = excelFile.next();
+        if (r2.getType() == Type.CONTINUE)
+        {
+          ContinueRecord formatting = new ContinueRecord(r2);
+          checkBox.setFormatting(formatting);
+        }
+
+        drawings.add(checkBox);
+
+        return;
       }
 
-      drawingData.addData(msoRecord.getData());
-
-      if (workbook.getDrawingGroup() != null) // can be null for Excel 95
+      // Handle form buttons
+      if (objRecord.getType() == ObjRecord.BUTTON)
       {
-        workbook.getDrawingGroup().setDrawingsOmitted(msoRecord,
-                                                      objRecord);
+        if (drawingData == null)
+        {
+          drawingData = new DrawingData();
+        }
+
+        Button button = new Button(msoRecord,
+                                   objRecord,
+                                   drawingData,
+                                   workbook.getDrawingGroup(),
+                                   workbookSettings);
+
+        Record r2 = excelFile.next();
+        if (r2.getType() == Type.MSODRAWING)
+        {
+          MsoDrawingRecord mso = new MsoDrawingRecord(r2);
+          button.addMso(mso);
+          r2 = excelFile.next();
+        }
+        Assert.verify(r2.getType() == Type.TXO);
+        TextObjectRecord txo = new TextObjectRecord(r2);
+        button.setTextObject(txo);
+
+        r2 = excelFile.next();
+        Assert.verify(r2.getType() == Type.CONTINUE);
+        ContinueRecord text = new ContinueRecord(r2);
+        button.setText(text);
+
+        r2 = excelFile.next();
+        if (r2.getType() == Type.CONTINUE)
+        {
+          ContinueRecord formatting = new ContinueRecord(r2);
+          button.setFormatting(formatting);
+        }
+
+        drawings.add(button);
+
+        return;
       }
 
-      return;
-    }
+      // Handle other types
+      if (objRecord.getType() != ObjRecord.CHART)
+      {
+        logger.warn(objRecord.getType() + " on sheet \"" +
+                    sheet.getName() +
+                    "\" not supported - omitting");
+
+        if (drawingData == null)
+        {
+          drawingData = new DrawingData();
+        }
+
+        drawingData.addData(msoRecord.getData());
+
+        if (workbook.getDrawingGroup() != null) // can be null for Excel 95
+        {
+          workbook.getDrawingGroup().setDrawingsOmitted(msoRecord,
+                                                        objRecord);
+        }
+
+        return;
+      }
     }
     catch (DrawingDataException e)
     {
