@@ -23,8 +23,8 @@ import java.util.ArrayList;
 import java.util.HashMap;
 import java.util.Iterator;
 
-import common.Assert;
-import common.Logger;
+import jxl.common.Assert;
+import jxl.common.Logger;
 
 import jxl.Cell;
 import jxl.Range;
@@ -38,12 +38,14 @@ import jxl.biff.FontRecord;
 import jxl.biff.Fonts;
 import jxl.biff.FormatRecord;
 import jxl.biff.FormattingRecords;
+import jxl.biff.NameRangeException;
 import jxl.biff.NumFormatRecordsException;
 import jxl.biff.PaletteRecord;
 import jxl.biff.RangeImpl;
 import jxl.biff.StringHelper;
 import jxl.biff.Type;
 import jxl.biff.WorkbookMethods;
+import jxl.biff.XCTRecord;
 import jxl.biff.XFRecord;
 import jxl.biff.drawing.DrawingGroup;
 import jxl.biff.drawing.MsoDrawingGroupRecord;
@@ -172,6 +174,8 @@ public class WorkbookParser extends Workbook
    */
   private CountryRecord countryRecord;
 
+  private ArrayList xctRecords;
+
   /**
    * Constructs this object from the raw excel data
    *
@@ -192,6 +196,7 @@ public class WorkbookParser extends Workbook
     wbProtected = false;
     containsMacros = false;
     settings = s;
+    xctRecords = new ArrayList(10);
   }
 
  /**
@@ -433,6 +438,7 @@ public class WorkbookParser extends Workbook
     }
 
     // An unknown supbook - return unkown
+    logger.warn("Unknown Supbook 3");
     return "[UNKNOWN]";
   }
 
@@ -487,6 +493,7 @@ public class WorkbookParser extends Workbook
     }
 
     // An unknown supbook - return unkown
+    logger.warn("Unknown Supbook 4");
     return "[UNKNOWN]";
   }
 
@@ -556,7 +563,7 @@ public class WorkbookParser extends Workbook
     nameTable = new ArrayList();
     addInFunctions = new ArrayList();
 
-    // Skip to the firs worksheet
+    // Skip to the first worksheet
     while (bofs == 1)
     {
       r = excelFile.next();
@@ -587,19 +594,22 @@ public class WorkbookParser extends Workbook
 
         if (bof.isBiff8())
         {
-          nr = new NameRecord(r, settings, namedRecords.size());
+          nr = new NameRecord(r, settings, nameTable.size());
         
         }
         else
         {
-          nr = new NameRecord(r, settings, namedRecords.size(),
+          nr = new NameRecord(r, settings, nameTable.size(),
                               NameRecord.biff7);
         }
 
+        // Add all local and global names to the name table in order to
+        // preserve the indexing
+        nameTable.add(nr);
+
         if (nr.isGlobal())
         {
           namedRecords.put(nr.getName(), nr);
-          nameTable.add(nr);
         }
         else
         {
@@ -708,6 +718,11 @@ public class WorkbookParser extends Workbook
                                                 ExternalSheetRecord.biff7);
         }
       }
+      else if (r.getType() == Type.XCT)
+      {
+        XCTRecord xctr = new XCTRecord(r);
+        xctRecords.add(xctr);
+      }
       else if (r.getType() == Type.CODEPAGE)
       {
         CodepageRecord cr = new CodepageRecord(r);
@@ -776,6 +791,42 @@ public class WorkbookParser extends Workbook
       {
         bofs--;
       }
+      else if (r.getType() == Type.REFRESHALL)
+      {
+        RefreshAllRecord rfm = new RefreshAllRecord(r);
+        settings.setRefreshAll(rfm.getRefreshAll());
+      }
+      else if (r.getType() == Type.TEMPLATE)
+      {
+        TemplateRecord rfm = new TemplateRecord(r);
+        settings.setTemplate(rfm.getTemplate());
+      }
+      else if (r.getType() == Type.EXCEL9FILE)
+      {
+        Excel9FileRecord e9f = new Excel9FileRecord(r);
+        settings.setExcel9File(e9f.getExcel9File());
+      }
+      else if (r.getType() == Type.WINDOWPROTECT)
+      {
+        WindowProtectedRecord winp = new WindowProtectedRecord(r);
+        settings.setWindowProtected(winp.getWindowProtected());
+      }
+      else if (r.getType() == Type.HIDEOBJ)
+      {
+        HideobjRecord hobj = new HideobjRecord(r);
+        settings.setHideobj(hobj.getHideMode());
+      }
+      else if (r.getType() == Type.WRITEACCESS)
+      {
+        WriteAccessRecord war = new WriteAccessRecord(r, bof.isBiff8(),
+                                                      settings);
+        settings.setWriteAccess(war.getWriteAccess());
+      }
+      else
+      {
+        // logger.info("Unsupported record type: " +
+        //            Integer.toHexString(r.getCode())+"h");
+      }
     }
 
     bof = null;
@@ -1112,10 +1163,15 @@ public class WorkbookParser extends Workbook
    *
    * @param index the index into the name table
    * @return the name of the cell
+   * @exception NameRangeException
    */
-  public String getName(int index)
+  public String getName(int index) throws NameRangeException
   {
-    Assert.verify(index >= 0 && index < nameTable.size());
+    //    Assert.verify(index >= 0 && index < nameTable.size());
+    if (index < 0 || index >= nameTable.size())
+    {
+      throw new NameRangeException();
+    }
     return ((NameRecord) nameTable.get(index)).getName();
   }
 
@@ -1225,6 +1281,12 @@ public class WorkbookParser extends Workbook
 
     return index;
   }
+
+  public XCTRecord[] getXCTRecords()
+  {
+    XCTRecord[] xctr = new XCTRecord[0];
+    return (XCTRecord[]) xctRecords.toArray(xctr);
+  }
 }
 
 
