@@ -23,7 +23,7 @@ import java.io.IOException;
 import java.util.ArrayList;
 import java.util.Iterator;
 
-import common.Logger;
+import jxl.common.Logger;
 
 import jxl.CellType;
 import jxl.SheetSettings;
