@@ -25,8 +25,8 @@ import java.util.HashMap;
 import java.util.TreeSet;
 import java.util.Iterator;
 
-import common.Assert;
-import common.Logger;
+import jxl.common.Assert;
+import jxl.common.Logger;
 
 import jxl.BooleanCell;
 import jxl.Cell;
@@ -53,6 +53,7 @@ import jxl.biff.NumFormatRecordsException;
 import jxl.biff.SheetRangeImpl;
 import jxl.biff.XFRecord;
 import jxl.biff.drawing.Chart;
+import jxl.biff.drawing.CheckBox;
 import jxl.biff.drawing.ComboBox;
 import jxl.biff.drawing.Drawing;
 import jxl.biff.drawing.DrawingGroupObject;
@@ -340,6 +341,16 @@ class SheetCopier
            workbookSettings);
         drawings.add(cb);
       }
+      else if (dr[i] instanceof jxl.biff.drawing.CheckBox)
+      {
+        jxl.biff.drawing.CheckBox cb = 
+          new jxl.biff.drawing.CheckBox
+          (dr[i], 
+           toSheet.getWorkbook().getDrawingGroup(), 
+           workbookSettings);
+        drawings.add(cb);
+      }
+
     }
 
     // Copy the data validations
