@@ -24,12 +24,14 @@ import java.util.ArrayList;
 import java.util.Comparator;
 import java.util.Iterator;
 import java.util.TreeSet;
+import java.util.regex.Pattern;
 
-import common.Assert;
-import common.Logger;
+import jxl.common.Assert;
+import jxl.common.Logger;
 
 import jxl.BooleanCell;
 import jxl.Cell;
+import jxl.CellFeatures;
 import jxl.CellType;
 import jxl.CellView;
 import jxl.DateCell;
@@ -44,6 +46,7 @@ import jxl.SheetSettings;
 import jxl.WorkbookSettings;
 import jxl.biff.AutoFilter;
 import jxl.biff.BuiltInName;
+import jxl.biff.CellFinder;
 import jxl.biff.CellReferenceHelper;
 import jxl.biff.ConditionalFormat;
 import jxl.biff.DataValidation;
@@ -439,29 +442,74 @@ class WritableSheetImpl implements WritableSheet
    * If no match is found, then null is returned.  The search is performed
    * on a row by row basis, so the lower the row number, the more
    * efficiently the algorithm will perform
-   * 
-   * @param contents the string to match
-   * @return the Cell whose contents match the parameter, null if not found
+   *
+   * @param  contents the string to match
+   * @return the Cell whose contents match the paramter, null if not found
    */
   public Cell findCell(String contents)
   {
-    Cell cell = null;
-    boolean found = false;
-    
-    for (int i = 0 ; i < getRows() && found == false; i++)
-    {
-      Cell[] row = getRow(i);
-      for (int j = 0 ; j < row.length && found == false; j++)
-      {
-        if (row[j].getContents().equals(contents))
-        {
-          cell = row[j];
-          found = true;
-        }
-      }
-    }
+    CellFinder cellFinder = new CellFinder(this);
+    return cellFinder.findCell(contents);
+  }
 
-    return cell;
+  /**
+   * Gets the cell whose contents match the string passed in.
+   * If no match is found, then null is returned.  The search is performed
+   * on a row by row basis, so the lower the row number, the more
+   * efficiently the algorithm will perform
+   * 
+   * @param contents the string to match
+   * @param firstCol the first column within the range
+   * @param firstRow the first row of the range
+   * @param lastCol the last column within the range
+   * @param lastRow the last row within the range
+   * @param reverse indicates whether to perform a reverse search or not
+   * @return the Cell whose contents match the parameter, null if not found
+   */
+  public Cell findCell(String contents, 
+                       int firstCol, 
+                       int firstRow, 
+                       int lastCol, 
+                       int lastRow, 
+                       boolean reverse)
+  {
+    CellFinder cellFinder = new CellFinder(this);
+    return cellFinder.findCell(contents,
+                               firstCol, 
+                               firstRow, 
+                               lastCol,
+                               lastRow, 
+                               reverse);
+  }
+
+  /**
+   * Gets the cell whose contents match the regular expressionstring passed in.
+   * If no match is found, then null is returned.  The search is performed
+   * on a row by row basis, so the lower the row number, the more
+   * efficiently the algorithm will perform
+   * 
+   * @param pattern the regular expression string to match
+   * @param firstCol the first column within the range
+   * @param firstRow the first row of the range
+   * @param lastRow the last row within the range
+   * @param lastCol the last column within the ranage
+   * @param reverse indicates whether to perform a reverse search or not
+   * @return the Cell whose contents match the parameter, null if not found
+   */
+  public Cell findCell(Pattern pattern, 
+                       int firstCol, 
+                       int firstRow, 
+                       int lastCol, 
+                       int lastRow, 
+                       boolean reverse)
+  {
+    CellFinder cellFinder = new CellFinder(this);
+    return cellFinder.findCell(pattern,
+                               firstCol, 
+                               firstRow, 
+                               lastCol,
+                               lastRow, 
+                               reverse);
   }
 
   /**
@@ -478,25 +526,8 @@ class WritableSheetImpl implements WritableSheet
    */
   public LabelCell findLabelCell(String contents)
   {
-    LabelCell cell = null;
-    boolean found = false;
-    
-    for (int i = 0 ; i < getRows() && found == false; i++)
-    {
-      Cell[] row = getRow(i);
-      for (int j = 0 ; j < row.length && found == false; j++)
-      {
-        if ( ( row[j].getType() == CellType.LABEL ||
-               row[j].getType() == CellType.STRING_FORMULA) &&
-            row[j].getContents().equals(contents))
-        {
-          cell = (LabelCell) row[j];
-          found = true;
-        }
-      }
-    }
-
-    return cell;
+    CellFinder cellFinder = new CellFinder(this);
+    return cellFinder.findLabelCell(contents);
   }
 
   /**
@@ -631,6 +662,19 @@ class WritableSheetImpl implements WritableSheet
       dataValidation.insertRow(row);
     }
 
+    if (validatedCells != null && validatedCells.size() > 0)
+    {
+      for (Iterator vci = validatedCells.iterator(); vci.hasNext();)
+      {
+        CellValue cv = (CellValue) vci.next();
+        CellFeatures cf = cv.getCellFeatures();
+        if (cf.getDVParser() != null)
+        {
+          cf.getDVParser().insertRow(row);
+        }
+      }
+    }
+
     // Adjust any merged cells
     mergedCells.insertRow(row);
 
@@ -736,6 +780,19 @@ class WritableSheetImpl implements WritableSheet
       dataValidation.insertColumn(col);
     }
 
+    if (validatedCells != null && validatedCells.size() > 0)
+    {
+      for (Iterator vci = validatedCells.iterator(); vci.hasNext();)
+      {
+        CellValue cv = (CellValue) vci.next();
+        CellFeatures cf = cv.getCellFeatures();
+        if (cf.getDVParser() != null)
+        {
+          cf.getDVParser().insertColumn(col);
+        }
+      }
+    }
+
     // Adjust any merged cells
     mergedCells.insertColumn(col);
 
@@ -804,7 +861,7 @@ class WritableSheetImpl implements WritableSheet
       {
         // The row with the hyperlink on has been removed, so get
         // rid of it from the list
-        hyperlinks.remove(hyperlinks.indexOf(hr));
+        i.remove();
       }
       else
       {
@@ -818,6 +875,19 @@ class WritableSheetImpl implements WritableSheet
       dataValidation.removeColumn(col);
     }
 
+    if (validatedCells != null && validatedCells.size() > 0)
+    {
+      for (Iterator vci = validatedCells.iterator(); vci.hasNext();)
+      {
+        CellValue cv = (CellValue) vci.next();
+        CellFeatures cf = cv.getCellFeatures();
+        if (cf.getDVParser() != null)
+        {
+          cf.getDVParser().removeColumn(col);
+        }
+      }
+    }
+
     // Adjust any merged cells
     mergedCells.removeColumn(col);
 
@@ -970,6 +1040,19 @@ class WritableSheetImpl implements WritableSheet
       dataValidation.removeRow(row);
     }
 
+    if (validatedCells != null && validatedCells.size() > 0)
+    {
+      for (Iterator vci = validatedCells.iterator(); vci.hasNext();)
+      {
+        CellValue cv = (CellValue) vci.next();
+        CellFeatures cf = cv.getCellFeatures();
+        if (cf.getDVParser() != null)
+        {
+          cf.getDVParser().removeRow(row);
+        }
+      }
+    }
+
     // Adjust any merged cells
     mergedCells.removeRow(row);
 
